@@ -5,3 +5,7 @@ class InvalidGlob(Exception):
 class PathNotFound(Exception):
     """One or more elements of the requested path did not exist in the object"""
     pass
+
+class InvalidKeyName(Exception):
+    """This key contains the separator character or another invalid character"""
+    pass
